// 内库使用
import GeoUtil from "./../../../GeoUtil";

// 测试使用
// import { GeoUtil } from 'seedsui-react'

// 坐标自动转换
/*
# 绘制地图瓦片
## 百度
- 国内: wgs84转为bd09渲染
- 国外: wgs84直接渲染

## 高德与Google
- 国内: wgs84转为gcj02渲染
- 国外: wgs84直接渲染



# 搜索附近
## 百度
- 国内搜索: wgs84转bd09后搜索
- 国内搜索结果: bd09转wgs84返回
- 国外搜索: wgs84搜索
- 国外搜索结果: wgs84直接返回

## 高德与Google
- 国内搜索: wgs84转gcj02后搜索
- 国内搜索结果: gcj02转wgs84返回
- 国外搜索: wgs84搜索
- 国外搜索结果: wgs84直接返回






# 地址逆解析
## 百度
- 国内: wgs84转bd09后解析
- 国内解析结果: bd09转wgs84返回
- 国外: wgs84解析
- 国外解析结果: wgs84直接返回

## 高德与Google
- 国内: wgs84转gcj02后解析
- 国内解析结果: gcj02转wgs84返回
- 国外: wgs84解析
- 国外解析结果: wgs84直接返回




# 获取当前位置
- 国内,国外: wgs84定位



# Leaflet API
# Leaflet绘制点L.marker
- 国内,国外: 使用wgs84绘点

# Leaflet中心位置panTo
- 国内,国外: wgs84
*/
function coordToFit(_ref) {
  var longitude = _ref.longitude,
    latitude = _ref.latitude,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? 'wgs84' : _ref$type,
    inChinaTo = _ref.inChinaTo;
  // 参数不合法
  if (!inChinaTo || !longitude || !latitude || !type) {
    return {
      longitude: longitude,
      latitude: latitude
    };
  }

  // 是否在中国
  var isInChina = GeoUtil.isInChina([longitude, latitude]) === true;

  // 在中国转为中国坐标bd09或gcj02
  var newPoint = isInChina ? GeoUtil.coordtransform([longitude, latitude], type, inChinaTo) : [longitude, latitude];

  // eslint-disable-next-line
  longitude = newPoint[0];
  // eslint-disable-next-line
  latitude = newPoint[1];
  return {
    longitude: longitude,
    latitude: latitude,
    isInChina: isInChina
  };
}

// 国内转gcj02, 国外转wgs84
function coordsToFit(coords) {
  if (Array.isArray(coords) && coords.length) {
    return coords.map(function (coord) {
      return coordToFit(coord);
    });
  } else if (toString.call(coords) === '[object Object]') {
    return coordToFit(coords);
  }
  return null;
}
export default coordsToFit;